@@ -1,5 +1,5 @@
 # Copyright 2019 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -248,23 +248,3 @@ def getsattr(obj, name, *default):
     value = getattr(obj, name, *default)
     setattr(obj, name, value)
     return value
-
-def maps(test, nexts=None, ins=None, outs=None, map=[]):
-    """Map a test.
-
-    :param test: test
-    :param nexts: next steps
-    :param ins: input steps
-    :param outs: output steps
-    """
-    if getattr(test.func, "node", None) is not None:
-        raise ValueError("test has already been mapped")
-
-    nexts = [Node.attributes(step).uid for step in nexts or []]
-    ins = [Node.attributes(step).uid for step in ins or []]
-    outs = [Node.attributes(step).uid for step in outs or []]
-
-    test.func.node = Node(*Node.attributes(test), nexts, ins, outs)
-
-    map.append(test.func.node)
-    return map
