@@ -1,5 +1,5 @@
 # Copyright 2019 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -940,6 +940,9 @@ class TestDefinition(object):
             type = parent.type
             subtype = parent.subtype
 
+        elif subtype is TestSubType.Example:
+            type = parent_type
+
         kwargs["subtype"] = subtype
         kwargs["type"] = type
 
