@@ -1,5 +1,5 @@
 # Copyright 2020 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -86,7 +86,9 @@ def format_type(msg):
     test_type = getattr(TestType, msg["test_type"])
     test_subtype = getattr(TestSubType, str(msg["test_subtype"]), 0)
 
-    if test_type == TestType.Module:
+    if test_subtype == TestSubType.Example:
+        return "Example"
+    elif test_type == TestType.Module:
         return "Module"
     elif test_type == TestType.Suite:
         if test_subtype == TestSubType.Feature:
